@@ -3,6 +3,7 @@ import json
 import logging
 
 import socketio
+import ujson as ujson
 
 
 class GSCNodeFunctionReceiverSocket:
@@ -20,7 +21,7 @@ class GSCNodeFunctionReceiverSocket:
 
         @self.sio.event
         def oncnodefunction(id, msg):
-            self.oncnodefunction(self.gsdbs, id, msg)
+            self.oncnodefunction(self.gsdbs, id, ujson.loads(msg))
 
         connectURL = ""
 
@@ -47,7 +48,7 @@ class GSCNodeFunctionReceiver:
         GSCNodeFunctionReceiverSocket.create(self.sio, self.gsdbs, self.oncnodefunction)
 
     def sendcnodefunctionanswer(self, id, msg):
-        self.sio.emit("answer", {"id": id, "message": json.dumps(msg)})
+        self.sio.emit("answer", {"id": id, "message": ujson.dumps(msg)})
 
 
 class GSCNodeFunctionCallerSocket:
